#!/usr/bin/env python
# daily_fluxes.py

"""
Author : peters 

Revision History:
File created on 20 Dec 2012.

"""

import os
import sys
import datetime
from dateutil.relativedelta import relativedelta
import subprocess

def monthly_avg(rundir,avg):
    """ Function to average a set of files in a folder from daily to monthly means """
    
    if avg not in ['transcom','olson','country','flux1x1']:
        raise IOError,'Choice of averaging invalid'
    if not os.path.exists(rundir):
        raise IOError,'rundir requested (%s) does not exist, exiting...'%rundir

    daydir = os.path.join(rundir , 'data_%s_daily'%avg)
    files  = os.listdir(daydir)
    monthdir = os.path.join(rundir,'data_%s_monthly'%avg)
    if not os.path.exists(monthdir):
        print "Creating new output directory " + monthdir
        os.makedirs(monthdir)
        sd = datetime.datetime(1999,1,1)
    else: 
        files_monthly = os.listdir(monthdir)
        files_monthly.sort()
        fm = files_monthly[-1]
        #sd = datetime.datetime(int(fm[9:13]),int(fm[14:16]),1)
        sd = datetime.datetime.strptime(fm.split('.')[-2],'%Y-%m')
    print sd
            
    files = [f for f in files if '-' in f]

    fileinfo = {}
    for filename in files:
        date=datetime.datetime.strptime(filename.split('.')[-2],'%Y-%m-%d')
        fileinfo[filename] = date

    years = [d.year for d in fileinfo.values()]
    months = set([d.month for d in fileinfo.values()])
    
    if sd > datetime.datetime(1999,2,1):
        sd = sd + relativedelta(months=+1)
    else: sd = datetime.datetime(min(years),1,1)
    ed = datetime.datetime(max(years)+1,1,1)

    while sd < ed: 

        nd = sd + relativedelta(months=+1)
        
        avg_files = [os.path.join(daydir,k) for k,v in fileinfo.iteritems() if v < nd and v >= sd]
        print sd, nd , len(avg_files)
       
        if len(avg_files) > 0: 
            command = ['ncra','-O']+ avg_files + [os.path.join(monthdir,'%s_fluxes.%s.nc'%(avg,sd.strftime('%Y-%m')))]
        
            status = subprocess.check_call(command)

        sd = nd

if __name__ == "__main__":

    try:
        rundir = sys.argv[1]
    except:
        rundir  = "/Storage/CO2/ivar/zeus_output/ICDC9/ctdas_co2c13_terdisbcb_manscale/analysis/"

    try:
        avg=sys.argv[2]
    except:
        avg='transcom'

    monthly_avg(rundir,avg)
