#!/usr/bin/env python
# daily_fluxes.py

"""
Author : peters 

Revision History:
File created on 20 Dec 2012.

"""

import os
import sys
import datetime
from dateutil.relativedelta import relativedelta
import subprocess

def yearly_avg(rundir,avg):
    """ Function to average a set of files in a folder from monthly to yearly means """

    if avg not in ['transcom','olson','country','flux1x1']:
        raise IOError,'Choice of averaging invalid'
    if not os.path.exists(rundir):
        raise IOError,'rundir requested (%s) does not exist, exiting...'%rundir

    monthdir = os.path.join(rundir , 'data_%s_monthly'%avg )
    files  = os.listdir(monthdir)
    yeardir = os.path.join(rundir,'data_%s_yearly'%avg)
    if not os.path.exists(yeardir):
        print "Creating new output directory " + yeardir
        os.makedirs(yeardir)
        sd = datetime.datetime(1999,1,1)
    else: 
        files_yearly = os.listdir(monthdir)
        files_yearly.sort()
            
    files = [f for f in files if '-' in f]

    fileinfo = {}
    for filename in files:
        date=datetime.datetime.strptime(filename.split('.')[-2],'%Y-%m')
        fileinfo[filename] = date

    years = set([d.year for d in fileinfo.values()])
    
    sd = datetime.datetime(min(years),1,1)
    ed = datetime.datetime(max(years)+1,1,1)

    while sd < ed: 

        nd = sd + relativedelta(years=+1)
        
        avg_files = [os.path.join(monthdir,k) for k,v in fileinfo.iteritems() if v < nd and v >= sd]
        print sd, nd , len(avg_files)
       
        if len(avg_files) > 0 : 
            command = ['ncra','-O']+ avg_files + [os.path.join(yeardir,'%s_fluxes.%s.nc'%(avg,sd.strftime('%Y')))]
        
            status = subprocess.check_call(command)

        sd = nd



if __name__ == "__main__":

    try:
        rundir = sys.argv[1]
    except:
        rundir  = "/Storage/CO2/ivar/zeus_output/ICDC9/ctdas_co2c13_terdisbcb_manscale/analysis/"

    try:
        avg=sys.argv[2]
    except:
        avg='transcom'


    yearly_avg(rundir,avg)

